# s1ard
[![Documentation Status][1]][2] [![PyPI version][4]][5]

**A prototype processor for Sentinel-1 Analysis Ready Data (ARD) backscatter products.**

Please refer to the [documentation][3] for more details about installation and 
usage instructions, general processor information and the API reference.

Further information about the S1-NRB product can also be found 
[here][6].

[1]: https://readthedocs.org/projects/s1ard/badge/?version=latest
[2]: https://s1ard.readthedocs.io/en/latest/?badge=latest
[3]: https://s1ard.readthedocs.io/en/latest/
[4]: https://badge.fury.io/py/s1ard.svg
[5]: https://badge.fury.io/py/s1ard
[6]: https://sentiwiki.copernicus.eu/web/s1-products#S1Products-Sentinel-1ARDNormalisedRadarBackscatter(NRB)ProductS1-Products-Sentinel-1-ARD-Normalised-Radar-Backscatter
